@@ -1,6 +1,6 @@
 use crate::{
     filehash::get_filehash,
-    yubi,
+    yubikey,
     zfs::{zfs_create, zfs_mount},
 };
 
@@ -8,7 +8,7 @@ use sha2::{Digest, Sha512};
 use std::process::exit;
 
 pub fn print_mode_yubi(pass: &String, slot: u8) {
-    let key = yubi::get_hash(&pass, slot); // Get encryption key
+    let key = yubikey::get_hash(&pass, slot); // Get encryption key
     let key = match key {
         Ok(key) => key,
         Err(error) => {
@@ -17,6 +17,7 @@ pub fn print_mode_yubi(pass: &String, slot: u8) {
         }
     };
     println!("{}", &key);
+    drop(key);
     exit(0);
 }
 
@@ -27,13 +28,17 @@ pub fn print_mode_file(pass: &String, file: &String, port: u16) {
     let key = [filehash, passhash].concat();
     let key = Sha512::digest(&key);
     println!("{:x}", &key);
+    drop(key);
     exit(0);
 }
 
 pub fn unlock_zfs_yubi(pass: String, zfspath: String, slot: u8) {
-    let key = yubi::get_hash(&pass, slot); // Get encryption key
+    let key = yubikey::get_hash(&pass, slot); // Get encryption key
     match key {
-        Ok(key) => zfs_mount(&key, zfspath),
+        Ok(key) => {
+            zfs_mount(&key, zfspath);
+            drop(key);
+        }
 
         Err(error) => {
             eprintln!("Error: Failed to calculate hash from Yubikey\n{}", error);
@@ -52,7 +57,8 @@ pub fn unlock_zfs_file(pass: String, file: String, dataset: String, port: u16) {
     let key = [filehash, passhash].concat();
     let key = Sha512::digest(&key);
     let key = format!("{:x}", key);
-    zfs_mount(&key, dataset)
+    zfs_mount(&key, dataset);
+    drop(key);
 }
 
 pub fn create_zfs_file(pass: String, file: String, dataset: String, port: u16) {
@@ -66,14 +72,18 @@ pub fn create_zfs_file(pass: String, file: String, dataset: String, port: u16) {
     let key = [filehash, passhash].concat();
     let key = Sha512::digest(&key);
     let key = format!("{:x}", key);
-    zfs_create(&key, dataset)
+    zfs_create(&key, dataset);
+    drop(key);
 }
 
 pub fn create_zfs_yubi(pass: String, zfspath: String, slot: u8) {
-    let key = yubi::get_hash(&pass, slot); // Get encryption key
+    let key = yubikey::get_hash(&pass, slot); // Get encryption key
     let zfspath = zfspath;
     match key {
-        Ok(key) => zfs_create(&key, zfspath),
+        Ok(key) => {
+            zfs_create(&key, zfspath);
+            drop(key);
+        }
         Err(error) => {
             eprintln!("Error: Failed to calculate hash from Yubikey\n{}", error);
             exit(1)
